Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1450)

Unified Diff: net/log/net_log.h

Issue 1535363003: Switch to standard integer types in net/. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: stddef Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/http/url_security_manager_win.cc ('k') | net/log/net_log.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/log/net_log.h
diff --git a/net/log/net_log.h b/net/log/net_log.h
index 1b3f27c77b590d6e4beeda4feb83b9614401beea..aac2e994f9a59f3a19146bf317adb8517641132a 100644
--- a/net/log/net_log.h
+++ b/net/log/net_log.h
@@ -5,14 +5,16 @@
#ifndef NET_LOG_NET_LOG_H_
#define NET_LOG_NET_LOG_H_
+#include <stdint.h>
+
#include <string>
#include "build/build_config.h"
#include "base/atomicops.h"
-#include "base/basictypes.h"
#include "base/callback_forward.h"
#include "base/compiler_specific.h"
+#include "base/macros.h"
#include "base/observer_list.h"
#include "base/strings/string16.h"
#include "base/synchronization/lock.h"
@@ -78,10 +80,10 @@ class NET_EXPORT NetLog {
// uniquely identify the source, and is used by log observers to infer
// message groupings. Can use NetLog::NextID() to create unique IDs.
struct NET_EXPORT Source {
- static const uint32 kInvalidId;
+ static const uint32_t kInvalidId;
Source();
- Source(SourceType type, uint32 id);
+ Source(SourceType type, uint32_t id);
bool IsValid() const;
// Adds the source to a DictionaryValue containing event parameters,
@@ -99,7 +101,7 @@ class NET_EXPORT NetLog {
static bool FromEventParameters(base::Value* event_params, Source* source);
SourceType type;
- uint32 id;
+ uint32_t id;
};
struct NET_EXPORT EntryData {
@@ -206,7 +208,7 @@ class NET_EXPORT NetLog {
// Returns a unique ID which can be used as a source ID. All returned IDs
// will be unique and greater than 0.
- uint32 NextID();
+ uint32_t NextID();
// Returns true if there are any observers attached to the NetLog. This can be
// used as an optimization to avoid emitting log entries when there is no
@@ -270,11 +272,11 @@ class NET_EXPORT NetLog {
// Warning: |name| must remain valid for the life of the callback.
static ParametersCallback IntCallback(const char* name, int value);
// Creates a ParametersCallback that encapsulates a single int64. The
// callback will return the value as a StringValue, since IntegerValues
// only support 32-bit values.
// Warning: |name| must remain valid for the life of the callback.
- static ParametersCallback Int64Callback(const char* name, int64 value);
+ static ParametersCallback Int64Callback(const char* name, int64_t value);
// Creates a ParametersCallback that encapsulates a single UTF8 string. Takes
// |value| as a pointer to avoid copying, and emphasize it must be valid for
« no previous file with comments | « net/http/url_security_manager_win.cc ('k') | net/log/net_log.cc » ('j') | no next file with comments »
@@ -270,11 +272,11 @@ class NET_EXPORT NetLog {
// Warning: |name| must remain valid for the life of the callback.
static ParametersCallback IntCallback(const char* name, int value);
- // Creates a ParametersCallback that encapsulates a single int64. The
+ // Creates a ParametersCallback that encapsulates a single int64_t. The
// callback will return the value as a StringValue, since IntegerValues
// only support 32-bit values.

Powered by Google App Engine
This is Rietveld 408576698